@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'cucumber/formatter/console'
 
 module Cucumber
@@ -30,7 +32,7 @@ module Cucumber
 
       def status_counts(summary)
         counts = Core::Test::Result::TYPES.map { |status| [status, summary.total(status)] }
-        counts = counts.select { |_status, count| count > 0 }
+        counts = counts.select { |_status, count| count.positive? }
         counts = counts.map { |status, count| format_string("#{count} #{status}", status) }
         "(#{counts.join(', ')})" if counts.any?
       end
